summaryrefslogtreecommitdiffstats
path: root/src/include/usr/devicefw
diff options
context:
space:
mode:
authorDan Crowell <dcrowell@us.ibm.com>2011-07-29 13:22:18 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2011-08-08 08:03:58 -0500
commitdf4b0117660700e195864b761dfe92dd3467c686 (patch)
tree8542d84e764200031416e89a5defa166a616e0d0 /src/include/usr/devicefw
parentb6041015e48c8987813b2220f59da4bf6c54383e (diff)
downloadtalos-hostboot-df4b0117660700e195864b761dfe92dd3467c686.tar.gz
talos-hostboot-df4b0117660700e195864b761dfe92dd3467c686.zip
More PNOR RP work - Task 3440 (Story 3330)
Also includes testcase work for Task 3388 Change-Id: Ib4ff920f351554fe457c171f601a38809ca6ac6f Functional PNOR RP code that works with the PNOR DD. Still missing the complete path but should be ready for use by the next level up. Task 3440 Change-Id: Id32a919f88da636c341116444e557387beaccdb2 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/230 Tested-by: Jenkins Server Reviewed-by: Douglas R. Gilbert <dgilbert@us.ibm.com> Reviewed-by: ADAM R. MUHLE <armuhle@us.ibm.com>
Diffstat (limited to 'src/include/usr/devicefw')
-rw-r--r--src/include/usr/devicefw/devfwreasoncodes.H2
-rw-r--r--src/include/usr/devicefw/userif.H10
2 files changed, 6 insertions, 6 deletions
diff --git a/src/include/usr/devicefw/devfwreasoncodes.H b/src/include/usr/devicefw/devfwreasoncodes.H
index 0f55f063d..16493ca5b 100644
--- a/src/include/usr/devicefw/devfwreasoncodes.H
+++ b/src/include/usr/devicefw/devfwreasoncodes.H
@@ -7,7 +7,7 @@ namespace DeviceFW
{
enum DevFwModuleId
{
- DEVFW_MOD_ASSOCIATOR = 0x00,
+ DEVFW_MOD_ASSOCIATOR = 0x01,
};
enum DevFwReasonCode
diff --git a/src/include/usr/devicefw/userif.H b/src/include/usr/devicefw/userif.H
index c1bbd864b..6c261caab 100644
--- a/src/include/usr/devicefw/userif.H
+++ b/src/include/usr/devicefw/userif.H
@@ -42,13 +42,13 @@ namespace DeviceFW
/**
* Construct a PNOR DD address
* address = 0000_0000_0000_000c_aaaa_aaaa_aaaa_aaaa
* c=side, a=address
* @param[in] chip Chip Select
* @param[in] addr Offset (from zero) into selected flash chip
* @return 64-bit address to pass into PNOR device commands
*/
- #define DEVICE_PNOR_ADDRESS( chip, addr ) \
- DeviceFW::PNOR, ((static_cast<uint64_t>(chip)<<32)|static_cast<uint64_t>(addr))
+ #define DEVICE_PNOR_ADDRESS( i_chip, i_addr ) \
+ DeviceFW::PNOR, ((static_cast<uint64_t>(i_chip)<<32)|static_cast<uint64_t>(i_addr))
/**
OpenPOWER on IntegriCloud
@@ -42,13 +42,13 @@ namespace DeviceFW
* Construct a PNOR DD address
* address = 0000_0000_0000_000c_aaaa_aaaa_aaaa_aaaa
- * c=side, a=address
- * @param[in] chip Chip Select
- * @param[in] addr Offset (from zero) into selected flash chip
+ * c=chip, a=address
+ * @param[in] i_chip Chip Select
+ * @param[in] i_addr Offset (from zero) into selected flash chip
* @return 64-bit address to pass into PNOR device commands
*/